Настройка сторонних программ
Пред. | Глава 3. Настройка | След.

## Настройка сторонних программ

В этой секции описана настройка программ, часто используемых вместе с ardj, но не имеющих к нему отношения.

### Загрузка музыки по протоколу SFTP

Протокол SFTP является безопасным аналогом протокола FTP, работающим поверх SSH. Для того, чтобы предоставить пользователям возможность безопасно (для сервера) загружать музыку, следует создать специального пользователя — назовём его "ardj-uploader" — для которого домашней папкой будет `/var/lib/ardj/incoming`, добавить его в группу "ardj", а в файл `/etc/ssh/sshd_config` добавить такие строки:

    Match Group ardj
    ChrootDirectory %h
    ForceCommand internal-sftp
    AllowTcpForwarding no

Теперь пользователь ardj-uploader может подключаться к серверу по протоколу SFTP и может складывать файлы в папку incoming; подключаться по SSH, загружать файлы в другие папки или доставать их оттуда он не может.

### Настройка ezstream и sox

В базовой конфигурации ezstream рекомендуется для декодирования файлов использовать специализированные утилиты для каждого формата: oggdec, madplay, flac. Этот вариант плох по двум причинам. Во-первых, эти утилиты не поддерживают ReplayGain, что для радиостанции критично. Во-вторых, не все их них поддерживают ресэмплинг, от чего монофонические файлы, если они попадаются в плейлисте, звучат ввое быстрее.

Эту проблему можно решить использованием в качестве декодера утилиты sox. Дополнительным преимуществом является простота: sox — это одна утилита, поддерживающая все форматы.

Для использования sox замените все описания декодеров в файле `/etc/ezstream.xml` на следующее:

    <decode>sox --replay-gain track "@T@" -r 44100 -c 2 -t raw -e signed-integer -</decode>

Пред. | Наверх | След.
Доступ к количеству слушателей | Начало | Управление доступом ко специальным командам